@@ -8,8 +8,8 @@
     :copyright: (c) 2013-present by Abhinav Singh and contributors.
     :license: BSD, see LICENSE for more details.
 """
-import socket
 import ssl
+import socket
 from typing import Optional, Union, Tuple
 
 from .connection import TcpConnection, tcpConnectionTypes, TcpConnectionUninitializedException
@@ -34,3 +34,14 @@ class TcpServerConnection(TcpConnection):
         if self._conn is not None:
             return
         self._conn = new_socket_connection(self.addr)
+
+    def wrap(self, hostname: str, ca_file: Optional[str]) -> None:
+        ctx = ssl.create_default_context(
+            ssl.Purpose.SERVER_AUTH, cafile=ca_file)
+        ctx.options |= ssl.OP_NO_SSLv2 | ssl.OP_NO_SSLv3 | ssl.OP_NO_TLSv1
+        ctx.check_hostname = True
+        self.connection.setblocking(True)
+        self._conn = ctx.wrap_socket(
+            self.connection,
+            server_hostname=hostname)
+        self.connection.setblocking(False)
