@@ -18,6 +18,9 @@ from .shortlink import ShortLinkPlugin
 from .web_server_route import WebServerPlugin
 from .reverse_proxy import ReverseProxyPlugin
 from .proxy_pool import ProxyPoolPlugin
+from .filter_by_client_ip import FilterByClientIpPlugin
+from .filter_by_url_regex import FilterByURLRegexPlugin
+from .modify_chunk_response import ModifyChunkResponsePlugin
 
 __all__ = [
     'CacheResponsesPlugin',
@@ -31,4 +34,7 @@ __all__ = [
     'WebServerPlugin',
     'ReverseProxyPlugin',
     'ProxyPoolPlugin',
+    'FilterByClientIpPlugin',
+    'ModifyChunkResponsePlugin',
+    'FilterByURLRegexPlugin',
 ]
